# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\nVgoogle/ads/googleads_v0/proto/enums/criterion_category_channel_availability_mode.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xd4\x01\n,CriterionCategoryChannelAvailabilityModeEnum\"\xa3\x01\n(CriterionCategoryChannelAvailabilityMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x10\n\x0c\x41LL_CHANNELS\x10\x02\x12!\n\x1d\x43HANNEL_TYPE_AND_ALL_SUBTYPES\x10\x03\x12$\n CHANNEL_TYPE_AND_SUBSET_SUBTYPES\x10\x04\x42\xde\x01\n!com.google.ads.googleads.v0.enumsB-CriterionCategoryChannelAvailabilityModeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE = _descriptor.EnumDescriptor(
  name='CriterionCategoryChannelAvailabilityMode',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALL_CHANNELS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_TYPE_AND_ALL_SUBTYPES', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANNEL_TYPE_AND_SUBSET_SUBTYPES', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=171,
  serialized_end=334,
)
_sym_db.RegisterEnumDescriptor(_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE)


_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM = _descriptor.Descriptor(
  name='CriterionCategoryChannelAvailabilityModeEnum',
  full_name='google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=334,
)

_CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM_CRITERIONCATEGORYCHANNELAVAILABILITYMODE.containing_type = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM
DESCRIPTOR.message_types_by_name['CriterionCategoryChannelAvailabilityModeEnum'] = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CriterionCategoryChannelAvailabilityModeEnum = _reflection.GeneratedProtocolMessageType('CriterionCategoryChannelAvailabilityModeEnum', (_message.Message,), dict(
  DESCRIPTOR = _CRITERIONCATEGORYCHANNELAVAILABILITYMODEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.criterion_category_channel_availability_mode_pb2'
  ,
  __doc__ = """Describes channel availability mode for a criterion availability -
  whether the availability is meant to include all advertising channels,
  or a particular channel with all its channel subtypes, or a channel with
  a certain subset of channel subtypes.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.CriterionCategoryChannelAvailabilityModeEnum)
  ))
_sym_db.RegisterMessage(CriterionCategoryChannelAvailabilityModeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB-CriterionCategoryChannelAvailabilityModeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\nGgoogle/ads/googleads_v0/proto/enums/real_estate_placeholder_field.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xa9\x03\n\x1eRealEstatePlaceholderFieldEnum\"\x86\x03\n\x1aRealEstatePlaceholderField\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nLISTING_ID\x10\x02\x12\x10\n\x0cLISTING_NAME\x10\x03\x12\r\n\tCITY_NAME\x10\x04\x12\x0f\n\x0b\x44\x45SCRIPTION\x10\x05\x12\x0b\n\x07\x41\x44\x44RESS\x10\x06\x12\t\n\x05PRICE\x10\x07\x12\x13\n\x0f\x46ORMATTED_PRICE\x10\x08\x12\r\n\tIMAGE_URL\x10\t\x12\x11\n\rPROPERTY_TYPE\x10\n\x12\x10\n\x0cLISTING_TYPE\x10\x0b\x12\x17\n\x13\x43ONTEXTUAL_KEYWORDS\x10\x0c\x12\x0e\n\nFINAL_URLS\x10\r\x12\x15\n\x11\x46INAL_MOBILE_URLS\x10\x0e\x12\x10\n\x0cTRACKING_URL\x10\x0f\x12\x14\n\x10\x41NDROID_APP_LINK\x10\x10\x12\x17\n\x13SIMILAR_LISTING_IDS\x10\x11\x12\x10\n\x0cIOS_APP_LINK\x10\x12\x12\x14\n\x10IOS_APP_STORE_ID\x10\x13\x42\xd0\x01\n!com.google.ads.googleads.v0.enumsB\x1fRealEstatePlaceholderFieldProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD = _descriptor.EnumDescriptor(
  name='RealEstatePlaceholderField',
  full_name='google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_ID', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_NAME', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CITY_NAME', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DESCRIPTION', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADDRESS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRICE', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FORMATTED_PRICE', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IMAGE_URL', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPERTY_TYPE', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LISTING_TYPE', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTEXTUAL_KEYWORDS', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URLS', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URLS', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_URL', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ANDROID_APP_LINK', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SIMILAR_LISTING_IDS', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_LINK', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IOS_APP_STORE_ID', index=19, number=19,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=142,
  serialized_end=532,
)
_sym_db.RegisterEnumDescriptor(_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD)


_REALESTATEPLACEHOLDERFIELDENUM = _descriptor.Descriptor(
  name='RealEstatePlaceholderFieldEnum',
  full_name='google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=532,
)

_REALESTATEPLACEHOLDERFIELDENUM_REALESTATEPLACEHOLDERFIELD.containing_type = _REALESTATEPLACEHOLDERFIELDENUM
DESCRIPTOR.message_types_by_name['RealEstatePlaceholderFieldEnum'] = _REALESTATEPLACEHOLDERFIELDENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RealEstatePlaceholderFieldEnum = _reflection.GeneratedProtocolMessageType('RealEstatePlaceholderFieldEnum', (_message.Message,), dict(
  DESCRIPTOR = _REALESTATEPLACEHOLDERFIELDENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.real_estate_placeholder_field_pb2'
  ,
  __doc__ = """Values for Real Estate placeholder fields. For more information about
  dynamic remarketing feeds, see
  https://support.google.com/google-ads/answer/6053288.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.RealEstatePlaceholderFieldEnum)
  ))
_sym_db.RegisterMessage(RealEstatePlaceholderFieldEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB\037RealEstatePlaceholderFieldProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/resources/customer_client_link.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.enums import manager_link_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_manager__link__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/resources/customer_client_link.proto',
  package='google.ads.googleads.v0.resources',
  syntax='proto3',
  serialized_pb=_b('\nBgoogle/ads/googleads_v0/proto/resources/customer_client_link.proto\x12!google.ads.googleads.v0.resources\x1a=google/ads/googleads_v0/proto/enums/manager_link_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9c\x02\n\x12\x43ustomerClientLink\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x35\n\x0f\x63lient_customer\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0fmanager_link_id\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12V\n\x06status\x18\x05 \x01(\x0e\x32\x46.google.ads.googleads.v0.enums.ManagerLinkStatusEnum.ManagerLinkStatus\x12*\n\x06hidden\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\xdc\x01\n%com.google.ads.googleads.v0.resourcesB\x17\x43ustomerClientLinkProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V0.Resources\xca\x02!Google\\Ads\\GoogleAds\\V0\\Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_manager__link__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_CUSTOMERCLIENTLINK = _descriptor.Descriptor(
  name='CustomerClientLink',
  full_name='google.ads.googleads.v0.resources.CustomerClientLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.resources.CustomerClientLink.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_customer', full_name='google.ads.googleads.v0.resources.CustomerClientLink.client_customer', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manager_link_id', full_name='google.ads.googleads.v0.resources.CustomerClientLink.manager_link_id', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v0.resources.CustomerClientLink.status', index=3,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hidden', full_name='google.ads.googleads.v0.resources.CustomerClientLink.hidden', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=485,
)

_CUSTOMERCLIENTLINK.fields_by_name['client_customer'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CUSTOMERCLIENTLINK.fields_by_name['manager_link_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CUSTOMERCLIENTLINK.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_enums_dot_manager__link__status__pb2._MANAGERLINKSTATUSENUM_MANAGERLINKSTATUS
_CUSTOMERCLIENTLINK.fields_by_name['hidden'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['CustomerClientLink'] = _CUSTOMERCLIENTLINK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomerClientLink = _reflection.GeneratedProtocolMessageType('CustomerClientLink', (_message.Message,), dict(
  DESCRIPTOR = _CUSTOMERCLIENTLINK,
  __module__ = 'google.ads.google_ads.v0.proto.resources.customer_client_link_pb2'
  ,
  __doc__ = """Represents customer client link relationship.
  
  
  Attributes:
      resource_name:
          Name of the resource. CustomerClientLink resource names have
          the form:  ``customers/{customer_id}/customerClientLinks/{clie
          nt_customer_id}_{manager_link_id}``
      client_customer:
          The client customer linked to this customer. Read only.
      manager_link_id:
          This is uniquely identifies a customer client link. Read only.
      status:
          This is the status of the link between client and manager.
      hidden:
          The visibility of the link. Users can choose whether or not to
          see hidden links in the AdWords UI. Default value is false
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.resources.CustomerClientLink)
  ))
_sym_db.RegisterMessage(CustomerClientLink)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%com.google.ads.googleads.v0.resourcesB\027CustomerClientLinkProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v0/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V0.Resources\312\002!Google\\Ads\\GoogleAds\\V0\\Resources'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/ad_group_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import ad_group_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/ad_group_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n=google/ads/googleads_v0/proto/services/ad_group_service.proto\x12 google.ads.googleads.v0.services\x1a\x36google/ads/googleads_v0/proto/resources/ad_group.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"*\n\x11GetAdGroupRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"t\n\x15MutateAdGroupsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12\x46\n\noperations\x18\x02 \x03(\x0b\x32\x32.google.ads.googleads.v0.services.AdGroupOperation\"\xde\x01\n\x10\x41\x64GroupOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x06\x63reate\x18\x01 \x01(\x0b\x32*.google.ads.googleads.v0.resources.AdGroupH\x00\x12<\n\x06update\x18\x02 \x01(\x0b\x32*.google.ads.googleads.v0.resources.AdGroupH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"`\n\x16MutateAdGroupsResponse\x12\x46\n\x07results\x18\x02 \x03(\x0b\x32\x35.google.ads.googleads.v0.services.MutateAdGroupResult\",\n\x13MutateAdGroupResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xf4\x02\n\x0e\x41\x64GroupService\x12\xa1\x01\n\nGetAdGroup\x12\x33.google.ads.googleads.v0.services.GetAdGroupRequest\x1a*.google.ads.googleads.v0.resources.AdGroup\"2\x82\xd3\xe4\x93\x02,\x12*/v0/{resource_name=customers/*/adGroups/*}\x12\xbd\x01\n\x0eMutateAdGroups\x12\x37.google.ads.googleads.v0.services.MutateAdGroupsRequest\x1a\x38.google.ads.googleads.v0.services.MutateAdGroupsResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/v0/customers/{customer_id=*}/adGroups:mutate:\x01*B\xd3\x01\n$com.google.ads.googleads.v0.servicesB\x13\x41\x64GroupServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETADGROUPREQUEST = _descriptor.Descriptor(
  name='GetAdGroupRequest',
  full_name='google.ads.googleads.v0.services.GetAdGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetAdGroupRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=261,
)


_MUTATEADGROUPSREQUEST = _descriptor.Descriptor(
  name='MutateAdGroupsRequest',
  full_name='google.ads.googleads.v0.services.MutateAdGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateAdGroupsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateAdGroupsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=379,
)


_ADGROUPOPERATION = _descriptor.Descriptor(
  name='AdGroupOperation',
  full_name='google.ads.googleads.v0.services.AdGroupOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.AdGroupOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.AdGroupOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.AdGroupOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.AdGroupOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.AdGroupOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=382,
  serialized_end=604,
)


_MUTATEADGROUPSRESPONSE = _descriptor.Descriptor(
  name='MutateAdGroupsResponse',
  full_name='google.ads.googleads.v0.services.MutateAdGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateAdGroupsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=702,
)


_MUTATEADGROUPRESULT = _descriptor.Descriptor(
  name='MutateAdGroupResult',
  full_name='google.ads.googleads.v0.services.MutateAdGroupResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateAdGroupResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=748,
)

_MUTATEADGROUPSREQUEST.fields_by_name['operations'].message_type = _ADGROUPOPERATION
_ADGROUPOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ADGROUPOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__pb2._ADGROUP
_ADGROUPOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__pb2._ADGROUP
_ADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPOPERATION.fields_by_name['create'])
_ADGROUPOPERATION.fields_by_name['create'].containing_oneof = _ADGROUPOPERATION.oneofs_by_name['operation']
_ADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPOPERATION.fields_by_name['update'])
_ADGROUPOPERATION.fields_by_name['update'].containing_oneof = _ADGROUPOPERATION.oneofs_by_name['operation']
_ADGROUPOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPOPERATION.fields_by_name['remove'])
_ADGROUPOPERATION.fields_by_name['remove'].containing_oneof = _ADGROUPOPERATION.oneofs_by_name['operation']
_MUTATEADGROUPSRESPONSE.fields_by_name['results'].message_type = _MUTATEADGROUPRESULT
DESCRIPTOR.message_types_by_name['GetAdGroupRequest'] = _GETADGROUPREQUEST
DESCRIPTOR.message_types_by_name['MutateAdGroupsRequest'] = _MUTATEADGROUPSREQUEST
DESCRIPTOR.message_types_by_name['AdGroupOperation'] = _ADGROUPOPERATION
DESCRIPTOR.message_types_by_name['MutateAdGroupsResponse'] = _MUTATEADGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['MutateAdGroupResult'] = _MUTATEADGROUPRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAdGroupRequest = _reflection.GeneratedProtocolMessageType('GetAdGroupRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETADGROUPREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupService.GetAdGroup][google.ads.googleads.v0.services.AdGroupService.GetAdGroup].
  
  
  Attributes:
      resource_name:
          The resource name of the ad group to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetAdGroupRequest)
  ))
_sym_db.RegisterMessage(GetAdGroupRequest)

MutateAdGroupsRequest = _reflection.GeneratedProtocolMessageType('MutateAdGroupsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupService.MutateAdGroups][google.ads.googleads.v0.services.AdGroupService.MutateAdGroups].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose ad groups are being modified.
      operations:
          The list of operations to perform on individual ad groups.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupsRequest)
  ))
_sym_db.RegisterMessage(MutateAdGroupsRequest)

AdGroupOperation = _reflection.GeneratedProtocolMessageType('AdGroupOperation', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an ad group.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new ad
          group.
      update:
          Update operation: The ad group is expected to have a valid
          resource name.
      remove:
          Remove operation: A resource name for the removed ad group is
          expected, in this format:
          ``customers/{customer_id}/adGroups/{ad_group_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.AdGroupOperation)
  ))
_sym_db.RegisterMessage(AdGroupOperation)

MutateAdGroupsResponse = _reflection.GeneratedProtocolMessageType('MutateAdGroupsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_service_pb2'
  ,
  __doc__ = """Response message for an ad group mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupsResponse)
  ))
_sym_db.RegisterMessage(MutateAdGroupsResponse)

MutateAdGroupResult = _reflection.GeneratedProtocolMessageType('MutateAdGroupResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_service_pb2'
  ,
  __doc__ = """The result for the ad group mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupResult)
  ))
_sym_db.RegisterMessage(MutateAdGroupResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\023AdGroupServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_ADGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='AdGroupService',
  full_name='google.ads.googleads.v0.services.AdGroupService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=751,
  serialized_end=1123,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAdGroup',
    full_name='google.ads.googleads.v0.services.AdGroupService.GetAdGroup',
    index=0,
    containing_service=None,
    input_type=_GETADGROUPREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__pb2._ADGROUP,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002,\022*/v0/{resource_name=customers/*/adGroups/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAdGroups',
    full_name='google.ads.googleads.v0.services.AdGroupService.MutateAdGroups',
    index=1,
    containing_service=None,
    input_type=_MUTATEADGROUPSREQUEST,
    output_type=_MUTATEADGROUPSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\"-/v0/customers/{customer_id=*}/adGroups:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADGROUPSERVICE)

DESCRIPTOR.services_by_name['AdGroupService'] = _ADGROUPSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/enums/policy_topic_evidence_destination_mismatch_url_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/enums/policy_topic_evidence_destination_mismatch_url_type.proto',
  package='google.ads.googleads.v0.enums',
  syntax='proto3',
  serialized_pb=_b('\n]google/ads/googleads_v0/proto/enums/policy_topic_evidence_destination_mismatch_url_type.proto\x12\x1dgoogle.ads.googleads.v0.enums\"\xe4\x01\n1PolicyTopicEvidenceDestinationMismatchUrlTypeEnum\"\xae\x01\n-PolicyTopicEvidenceDestinationMismatchUrlType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0f\n\x0b\x44ISPLAY_URL\x10\x02\x12\r\n\tFINAL_URL\x10\x03\x12\x14\n\x10\x46INAL_MOBILE_URL\x10\x04\x12\x10\n\x0cTRACKING_URL\x10\x05\x12\x17\n\x13MOBILE_TRACKING_URL\x10\x06\x42\xe3\x01\n!com.google.ads.googleads.v0.enumsB2PolicyTopicEvidenceDestinationMismatchUrlTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V0.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V0\\Enumsb\x06proto3')
)



_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPE = _descriptor.EnumDescriptor(
  name='PolicyTopicEvidenceDestinationMismatchUrlType',
  full_name='google.ads.googleads.v0.enums.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISPLAY_URL', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_URL', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FINAL_MOBILE_URL', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACKING_URL', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOBILE_TRACKING_URL', index=6, number=6,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=183,
  serialized_end=357,
)
_sym_db.RegisterEnumDescriptor(_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPE)


_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM = _descriptor.Descriptor(
  name='PolicyTopicEvidenceDestinationMismatchUrlTypeEnum',
  full_name='google.ads.googleads.v0.enums.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=357,
)

_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPE.containing_type = _POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM
DESCRIPTOR.message_types_by_name['PolicyTopicEvidenceDestinationMismatchUrlTypeEnum'] = _POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolicyTopicEvidenceDestinationMismatchUrlTypeEnum = _reflection.GeneratedProtocolMessageType('PolicyTopicEvidenceDestinationMismatchUrlTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM,
  __module__ = 'google.ads.google_ads.v0.proto.enums.policy_topic_evidence_destination_mismatch_url_type_pb2'
  ,
  __doc__ = """Container for enum describing possible policy topic evidence destination
  mismatch url types.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.enums.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum)
  ))
_sym_db.RegisterMessage(PolicyTopicEvidenceDestinationMismatchUrlTypeEnum)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!com.google.ads.googleads.v0.enumsB2PolicyTopicEvidenceDestinationMismatchUrlTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v0/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V0.Enums\312\002\035Google\\Ads\\GoogleAds\\V0\\Enums'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/shared_criterion_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import shared_criterion_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_shared__criterion__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/shared_criterion_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nEgoogle/ads/googleads_v0/proto/services/shared_criterion_service.proto\x12 google.ads.googleads.v0.services\x1a>google/ads/googleads_v0/proto/resources/shared_criterion.proto\x1a\x1cgoogle/api/annotations.proto\"2\n\x19GetSharedCriterionRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x82\x01\n\x1bMutateSharedCriteriaRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12N\n\noperations\x18\x02 \x03(\x0b\x32:.google.ads.googleads.v0.services.SharedCriterionOperation\"\x7f\n\x18SharedCriterionOperation\x12\x44\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x32.google.ads.googleads.v0.resources.SharedCriterionH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"n\n\x1cMutateSharedCriteriaResponse\x12N\n\x07results\x18\x02 \x03(\x0b\x32=.google.ads.googleads.v0.services.MutateSharedCriterionResult\"4\n\x1bMutateSharedCriterionResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xb2\x03\n\x16SharedCriterionService\x12\xbf\x01\n\x12GetSharedCriterion\x12;.google.ads.googleads.v0.services.GetSharedCriterionRequest\x1a\x32.google.ads.googleads.v0.resources.SharedCriterion\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/v0/{resource_name=customers/*/sharedCriteria/*}\x12\xd5\x01\n\x14MutateSharedCriteria\x12=.google.ads.googleads.v0.services.MutateSharedCriteriaRequest\x1a>.google.ads.googleads.v0.services.MutateSharedCriteriaResponse\">\x82\xd3\xe4\x93\x02\x38\"3/v0/customers/{customer_id=*}/sharedCriteria:mutate:\x01*B\xdb\x01\n$com.google.ads.googleads.v0.servicesB\x1bSharedCriterionServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_shared__criterion__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETSHAREDCRITERIONREQUEST = _descriptor.Descriptor(
  name='GetSharedCriterionRequest',
  full_name='google.ads.googleads.v0.services.GetSharedCriterionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetSharedCriterionRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=201,
  serialized_end=251,
)


_MUTATESHAREDCRITERIAREQUEST = _descriptor.Descriptor(
  name='MutateSharedCriteriaRequest',
  full_name='google.ads.googleads.v0.services.MutateSharedCriteriaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateSharedCriteriaRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateSharedCriteriaRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=384,
)


_SHAREDCRITERIONOPERATION = _descriptor.Descriptor(
  name='SharedCriterionOperation',
  full_name='google.ads.googleads.v0.services.SharedCriterionOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.SharedCriterionOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.SharedCriterionOperation.remove', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.SharedCriterionOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=386,
  serialized_end=513,
)


_MUTATESHAREDCRITERIARESPONSE = _descriptor.Descriptor(
  name='MutateSharedCriteriaResponse',
  full_name='google.ads.googleads.v0.services.MutateSharedCriteriaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateSharedCriteriaResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=625,
)


_MUTATESHAREDCRITERIONRESULT = _descriptor.Descriptor(
  name='MutateSharedCriterionResult',
  full_name='google.ads.googleads.v0.services.MutateSharedCriterionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateSharedCriterionResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=679,
)

_MUTATESHAREDCRITERIAREQUEST.fields_by_name['operations'].message_type = _SHAREDCRITERIONOPERATION
_SHAREDCRITERIONOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_shared__criterion__pb2._SHAREDCRITERION
_SHAREDCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _SHAREDCRITERIONOPERATION.fields_by_name['create'])
_SHAREDCRITERIONOPERATION.fields_by_name['create'].containing_oneof = _SHAREDCRITERIONOPERATION.oneofs_by_name['operation']
_SHAREDCRITERIONOPERATION.oneofs_by_name['operation'].fields.append(
  _SHAREDCRITERIONOPERATION.fields_by_name['remove'])
_SHAREDCRITERIONOPERATION.fields_by_name['remove'].containing_oneof = _SHAREDCRITERIONOPERATION.oneofs_by_name['operation']
_MUTATESHAREDCRITERIARESPONSE.fields_by_name['results'].message_type = _MUTATESHAREDCRITERIONRESULT
DESCRIPTOR.message_types_by_name['GetSharedCriterionRequest'] = _GETSHAREDCRITERIONREQUEST
DESCRIPTOR.message_types_by_name['MutateSharedCriteriaRequest'] = _MUTATESHAREDCRITERIAREQUEST
DESCRIPTOR.message_types_by_name['SharedCriterionOperation'] = _SHAREDCRITERIONOPERATION
DESCRIPTOR.message_types_by_name['MutateSharedCriteriaResponse'] = _MUTATESHAREDCRITERIARESPONSE
DESCRIPTOR.message_types_by_name['MutateSharedCriterionResult'] = _MUTATESHAREDCRITERIONRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetSharedCriterionRequest = _reflection.GeneratedProtocolMessageType('GetSharedCriterionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSHAREDCRITERIONREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [SharedCriterionService.GetSharedCriterion][google.ads.googleads.v0.services.SharedCriterionService.GetSharedCriterion].
  
  
  Attributes:
      resource_name:
          The resource name of the shared criterion to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetSharedCriterionRequest)
  ))
_sym_db.RegisterMessage(GetSharedCriterionRequest)

MutateSharedCriteriaRequest = _reflection.GeneratedProtocolMessageType('MutateSharedCriteriaRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIAREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Request message for
  [SharedCriterionService.MutateSharedCriteria][google.ads.googleads.v0.services.SharedCriterionService.MutateSharedCriteria].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose shared criteria are being
          modified.
      operations:
          The list of operations to perform on individual shared
          criteria.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateSharedCriteriaRequest)
  ))
_sym_db.RegisterMessage(MutateSharedCriteriaRequest)

SharedCriterionOperation = _reflection.GeneratedProtocolMessageType('SharedCriterionOperation', (_message.Message,), dict(
  DESCRIPTOR = _SHAREDCRITERIONOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on an shared criterion.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          shared criterion.
      remove:
          Remove operation: A resource name for the removed shared
          criterion is expected, in this format:  ``customers/{customer_
          id}/sharedCriteria/{shared_set_id}_{criterion_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.SharedCriterionOperation)
  ))
_sym_db.RegisterMessage(SharedCriterionOperation)

MutateSharedCriteriaResponse = _reflection.GeneratedProtocolMessageType('MutateSharedCriteriaResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIARESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """Response message for a shared criterion mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateSharedCriteriaResponse)
  ))
_sym_db.RegisterMessage(MutateSharedCriteriaResponse)

MutateSharedCriterionResult = _reflection.GeneratedProtocolMessageType('MutateSharedCriterionResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATESHAREDCRITERIONRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.shared_criterion_service_pb2'
  ,
  __doc__ = """The result for the shared criterion mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateSharedCriterionResult)
  ))
_sym_db.RegisterMessage(MutateSharedCriterionResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\033SharedCriterionServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_SHAREDCRITERIONSERVICE = _descriptor.ServiceDescriptor(
  name='SharedCriterionService',
  full_name='google.ads.googleads.v0.services.SharedCriterionService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=682,
  serialized_end=1116,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetSharedCriterion',
    full_name='google.ads.googleads.v0.services.SharedCriterionService.GetSharedCriterion',
    index=0,
    containing_service=None,
    input_type=_GETSHAREDCRITERIONREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_shared__criterion__pb2._SHAREDCRITERION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0022\0220/v0/{resource_name=customers/*/sharedCriteria/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateSharedCriteria',
    full_name='google.ads.googleads.v0.services.SharedCriterionService.MutateSharedCriteria',
    index=1,
    containing_service=None,
    input_type=_MUTATESHAREDCRITERIAREQUEST,
    output_type=_MUTATESHAREDCRITERIARESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0028\"3/v0/customers/{customer_id=*}/sharedCriteria:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_SHAREDCRITERIONSERVICE)

DESCRIPTOR.services_by_name['SharedCriterionService'] = _SHAREDCRITERIONSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/common/dates.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/common/dates.proto',
  package='google.ads.googleads.v0.common',
  syntax='proto3',
  serialized_pb=_b('\n0google/ads/googleads_v0/proto/common/dates.proto\x12\x1egoogle.ads.googleads.v0.common\x1a\x1egoogle/protobuf/wrappers.proto\"m\n\tDateRange\x12\x30\n\nstart_date\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65nd_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xc0\x01\n\"com.google.ads.googleads.v0.commonB\nDatesProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V0.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V0\\Commonb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])




_DATERANGE = _descriptor.Descriptor(
  name='DateRange',
  full_name='google.ads.googleads.v0.common.DateRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_date', full_name='google.ads.googleads.v0.common.DateRange.start_date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='google.ads.googleads.v0.common.DateRange.end_date', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=225,
)

_DATERANGE.fields_by_name['start_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DATERANGE.fields_by_name['end_date'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['DateRange'] = _DATERANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DateRange = _reflection.GeneratedProtocolMessageType('DateRange', (_message.Message,), dict(
  DESCRIPTOR = _DATERANGE,
  __module__ = 'google.ads.google_ads.v0.proto.common.dates_pb2'
  ,
  __doc__ = """A date range.
  
  
  Attributes:
      start_date:
          The start date, in yyyy-mm-dd format.
      end_date:
          The end date, in yyyy-mm-dd format.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.common.DateRange)
  ))
_sym_db.RegisterMessage(DateRange)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\"com.google.ads.googleads.v0.commonB\nDatesProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v0/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V0.Common\312\002\036Google\\Ads\\GoogleAds\\V0\\Common'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/keyword_plan_negative_keyword_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import keyword_plan_negative_keyword_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/keyword_plan_negative_keyword_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\nRgoogle/ads/googleads_v0/proto/services/keyword_plan_negative_keyword_service.proto\x12 google.ads.googleads.v0.services\x1aKgoogle/ads/googleads_v0/proto/resources/keyword_plan_negative_keyword.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\"=\n$GetKeywordPlanNegativeKeywordRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x9a\x01\n(MutateKeywordPlanNegativeKeywordsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12Y\n\noperations\x18\x02 \x03(\x0b\x32\x45.google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation\"\x97\x02\n#KeywordPlanNegativeKeywordOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12O\n\x06\x63reate\x18\x01 \x01(\x0b\x32=.google.ads.googleads.v0.resources.KeywordPlanNegativeKeywordH\x00\x12O\n\x06update\x18\x02 \x01(\x0b\x32=.google.ads.googleads.v0.resources.KeywordPlanNegativeKeywordH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"\x86\x01\n)MutateKeywordPlanNegativeKeywordsResponse\x12Y\n\x07results\x18\x02 \x03(\x0b\x32H.google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordResult\"?\n&MutateKeywordPlanNegativeKeywordResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x9f\x04\n!KeywordPlanNegativeKeywordService\x12\xed\x01\n\x1dGetKeywordPlanNegativeKeyword\x12\x46.google.ads.googleads.v0.services.GetKeywordPlanNegativeKeywordRequest\x1a=.google.ads.googleads.v0.resources.KeywordPlanNegativeKeyword\"E\x82\xd3\xe4\x93\x02?\x12=/v0/{resource_name=customers/*/keywordPlanNegativeKeywords/*}\x12\x89\x02\n!MutateKeywordPlanNegativeKeywords\x12J.google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsRequest\x1aK.google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsResponse\"K\x82\xd3\xe4\x93\x02\x45\"@/v0/customers/{customer_id=*}/keywordPlanNegativeKeywords:mutate:\x01*B\xe6\x01\n$com.google.ads.googleads.v0.servicesB&KeywordPlanNegativeKeywordServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETKEYWORDPLANNEGATIVEKEYWORDREQUEST = _descriptor.Descriptor(
  name='GetKeywordPlanNegativeKeywordRequest',
  full_name='google.ads.googleads.v0.services.GetKeywordPlanNegativeKeywordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetKeywordPlanNegativeKeywordRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=261,
  serialized_end=322,
)


_MUTATEKEYWORDPLANNEGATIVEKEYWORDSREQUEST = _descriptor.Descriptor(
  name='MutateKeywordPlanNegativeKeywordsRequest',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=325,
  serialized_end=479,
)


_KEYWORDPLANNEGATIVEKEYWORDOPERATION = _descriptor.Descriptor(
  name='KeywordPlanNegativeKeywordOperation',
  full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation.create', index=1,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation.update', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation.remove', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=482,
  serialized_end=761,
)


_MUTATEKEYWORDPLANNEGATIVEKEYWORDSRESPONSE = _descriptor.Descriptor(
  name='MutateKeywordPlanNegativeKeywordsResponse',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=764,
  serialized_end=898,
)


_MUTATEKEYWORDPLANNEGATIVEKEYWORDRESULT = _descriptor.Descriptor(
  name='MutateKeywordPlanNegativeKeywordResult',
  full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=900,
  serialized_end=963,
)

_MUTATEKEYWORDPLANNEGATIVEKEYWORDSREQUEST.fields_by_name['operations'].message_type = _KEYWORDPLANNEGATIVEKEYWORDOPERATION
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2._KEYWORDPLANNEGATIVEKEYWORD
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2._KEYWORDPLANNEGATIVEKEYWORD
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['create'])
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['create'].containing_oneof = _KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation']
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['update'])
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['update'].containing_oneof = _KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation']
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation'].fields.append(
  _KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['remove'])
_KEYWORDPLANNEGATIVEKEYWORDOPERATION.fields_by_name['remove'].containing_oneof = _KEYWORDPLANNEGATIVEKEYWORDOPERATION.oneofs_by_name['operation']
_MUTATEKEYWORDPLANNEGATIVEKEYWORDSRESPONSE.fields_by_name['results'].message_type = _MUTATEKEYWORDPLANNEGATIVEKEYWORDRESULT
DESCRIPTOR.message_types_by_name['GetKeywordPlanNegativeKeywordRequest'] = _GETKEYWORDPLANNEGATIVEKEYWORDREQUEST
DESCRIPTOR.message_types_by_name['MutateKeywordPlanNegativeKeywordsRequest'] = _MUTATEKEYWORDPLANNEGATIVEKEYWORDSREQUEST
DESCRIPTOR.message_types_by_name['KeywordPlanNegativeKeywordOperation'] = _KEYWORDPLANNEGATIVEKEYWORDOPERATION
DESCRIPTOR.message_types_by_name['MutateKeywordPlanNegativeKeywordsResponse'] = _MUTATEKEYWORDPLANNEGATIVEKEYWORDSRESPONSE
DESCRIPTOR.message_types_by_name['MutateKeywordPlanNegativeKeywordResult'] = _MUTATEKEYWORDPLANNEGATIVEKEYWORDRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetKeywordPlanNegativeKeywordRequest = _reflection.GeneratedProtocolMessageType('GetKeywordPlanNegativeKeywordRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETKEYWORDPLANNEGATIVEKEYWORDREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_negative_keyword_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanNegativeKeywordService.GetKeywordPlanNegativeKeyword][google.ads.googleads.v0.services.KeywordPlanNegativeKeywordService.GetKeywordPlanNegativeKeyword].
  
  
  Attributes:
      resource_name:
          The resource name of the plan to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetKeywordPlanNegativeKeywordRequest)
  ))
_sym_db.RegisterMessage(GetKeywordPlanNegativeKeywordRequest)

MutateKeywordPlanNegativeKeywordsRequest = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanNegativeKeywordsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANNEGATIVEKEYWORDSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_negative_keyword_service_pb2'
  ,
  __doc__ = """Request message for
  [KeywordPlanNegativeKeywordService.MutateKeywordPlanNegativeKeywords][google.ads.googleads.v0.services.KeywordPlanNegativeKeywordService.MutateKeywordPlanNegativeKeywords].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose negative keywords are being
          modified.
      operations:
          The list of operations to perform on individual Keyword Plan
          negative keywords.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsRequest)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanNegativeKeywordsRequest)

KeywordPlanNegativeKeywordOperation = _reflection.GeneratedProtocolMessageType('KeywordPlanNegativeKeywordOperation', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANNEGATIVEKEYWORDOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_negative_keyword_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on a Keyword Plan negative
  keyword.
  
  
  Attributes:
      update_mask:
          The FieldMask that determines which resource fields are
          modified in an update.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          Keyword Plan negative keyword.
      update:
          Update operation: The Keyword Plan negative keyword expected
          to have a valid resource name.
      remove:
          Remove operation: A resource name for the removed Keyword Plan
          negative keywords expected in this format:  ``customers/{custo
          mer_id}/keywordPlanNegativeKeywords/{kp_negative_keyword_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.KeywordPlanNegativeKeywordOperation)
  ))
_sym_db.RegisterMessage(KeywordPlanNegativeKeywordOperation)

MutateKeywordPlanNegativeKeywordsResponse = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanNegativeKeywordsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANNEGATIVEKEYWORDSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_negative_keyword_service_pb2'
  ,
  __doc__ = """Response message for a Keyword Plan negative keyword mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordsResponse)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanNegativeKeywordsResponse)

MutateKeywordPlanNegativeKeywordResult = _reflection.GeneratedProtocolMessageType('MutateKeywordPlanNegativeKeywordResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEKEYWORDPLANNEGATIVEKEYWORDRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.keyword_plan_negative_keyword_service_pb2'
  ,
  __doc__ = """The result for the Keyword Plan negative keyword mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateKeywordPlanNegativeKeywordResult)
  ))
_sym_db.RegisterMessage(MutateKeywordPlanNegativeKeywordResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB&KeywordPlanNegativeKeywordServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_KEYWORDPLANNEGATIVEKEYWORDSERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanNegativeKeywordService',
  full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=966,
  serialized_end=1509,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetKeywordPlanNegativeKeyword',
    full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordService.GetKeywordPlanNegativeKeyword',
    index=0,
    containing_service=None,
    input_type=_GETKEYWORDPLANNEGATIVEKEYWORDREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_keyword__plan__negative__keyword__pb2._KEYWORDPLANNEGATIVEKEYWORD,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002?\022=/v0/{resource_name=customers/*/keywordPlanNegativeKeywords/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateKeywordPlanNegativeKeywords',
    full_name='google.ads.googleads.v0.services.KeywordPlanNegativeKeywordService.MutateKeywordPlanNegativeKeywords',
    index=1,
    containing_service=None,
    input_type=_MUTATEKEYWORDPLANNEGATIVEKEYWORDSREQUEST,
    output_type=_MUTATEKEYWORDPLANNEGATIVEKEYWORDSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002E\"@/v0/customers/{customer_id=*}/keywordPlanNegativeKeywords:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANNEGATIVEKEYWORDSERVICE)

DESCRIPTOR.services_by_name['KeywordPlanNegativeKeywordService'] = _KEYWORDPLANNEGATIVEKEYWORDSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v0.proto.resources import change_status_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_change__status__pb2
from google.ads.google_ads.v0.proto.services import change_status_service_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_change__status__service__pb2


class ChangeStatusServiceStub(object):
  """Service to fetch change statuses.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetChangeStatus = channel.unary_unary(
        '/google.ads.googleads.v0.services.ChangeStatusService/GetChangeStatus',
        request_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_change__status__service__pb2.GetChangeStatusRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_change__status__pb2.ChangeStatus.FromString,
        )


class ChangeStatusServiceServicer(object):
  """Service to fetch change statuses.
  """

  def GetChangeStatus(self, request, context):
    """Returns the requested change status in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ChangeStatusServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetChangeStatus': grpc.unary_unary_rpc_method_handler(
          servicer.GetChangeStatus,
          request_deserializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_services_dot_change__status__service__pb2.GetChangeStatusRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_change__status__pb2.ChangeStatus.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v0.services.ChangeStatusService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/ad_group_ad_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v0.proto.resources import ad_group_ad_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__ad__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/ad_group_ad_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n@google/ads/googleads_v0/proto/services/ad_group_ad_service.proto\x12 google.ads.googleads.v0.services\x1a\x31google/ads/googleads_v0/proto/common/policy.proto\x1a\x39google/ads/googleads_v0/proto/resources/ad_group_ad.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\",\n\x13GetAdGroupAdRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"x\n\x17MutateAdGroupAdsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12H\n\noperations\x18\x02 \x03(\x0b\x32\x34.google.ads.googleads.v0.services.AdGroupAdOperation\"\xc4\x02\n\x12\x41\x64GroupAdOperation\x12/\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12^\n\x1bpolicy_validation_parameter\x18\x05 \x01(\x0b\x32\x39.google.ads.googleads.v0.common.PolicyValidationParameter\x12>\n\x06\x63reate\x18\x01 \x01(\x0b\x32,.google.ads.googleads.v0.resources.AdGroupAdH\x00\x12>\n\x06update\x18\x02 \x01(\x0b\x32,.google.ads.googleads.v0.resources.AdGroupAdH\x00\x12\x10\n\x06remove\x18\x03 \x01(\tH\x00\x42\x0b\n\toperation\"d\n\x18MutateAdGroupAdsResponse\x12H\n\x07results\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v0.services.MutateAdGroupAdResult\".\n\x15MutateAdGroupAdResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x86\x03\n\x10\x41\x64GroupAdService\x12\xa9\x01\n\x0cGetAdGroupAd\x12\x35.google.ads.googleads.v0.services.GetAdGroupAdRequest\x1a,.google.ads.googleads.v0.resources.AdGroupAd\"4\x82\xd3\xe4\x93\x02.\x12,/v0/{resource_name=customers/*/adGroupAds/*}\x12\xc5\x01\n\x10MutateAdGroupAds\x12\x39.google.ads.googleads.v0.services.MutateAdGroupAdsRequest\x1a:.google.ads.googleads.v0.services.MutateAdGroupAdsResponse\":\x82\xd3\xe4\x93\x02\x34\"//v0/customers/{customer_id=*}/adGroupAds:mutate:\x01*B\xd5\x01\n$com.google.ads.googleads.v0.servicesB\x15\x41\x64GroupAdServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__ad__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,])




_GETADGROUPADREQUEST = _descriptor.Descriptor(
  name='GetAdGroupAdRequest',
  full_name='google.ads.googleads.v0.services.GetAdGroupAdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetAdGroupAdRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=320,
)


_MUTATEADGROUPADSREQUEST = _descriptor.Descriptor(
  name='MutateAdGroupAdsRequest',
  full_name='google.ads.googleads.v0.services.MutateAdGroupAdsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateAdGroupAdsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateAdGroupAdsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=442,
)


_ADGROUPADOPERATION = _descriptor.Descriptor(
  name='AdGroupAdOperation',
  full_name='google.ads.googleads.v0.services.AdGroupAdOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.update_mask', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_validation_parameter', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.policy_validation_parameter', index=1,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.create', index=2,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.update', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.remove', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.AdGroupAdOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=445,
  serialized_end=769,
)


_MUTATEADGROUPADSRESPONSE = _descriptor.Descriptor(
  name='MutateAdGroupAdsResponse',
  full_name='google.ads.googleads.v0.services.MutateAdGroupAdsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateAdGroupAdsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=871,
)


_MUTATEADGROUPADRESULT = _descriptor.Descriptor(
  name='MutateAdGroupAdResult',
  full_name='google.ads.googleads.v0.services.MutateAdGroupAdResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateAdGroupAdResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=873,
  serialized_end=919,
)

_MUTATEADGROUPADSREQUEST.fields_by_name['operations'].message_type = _ADGROUPADOPERATION
_ADGROUPADOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ADGROUPADOPERATION.fields_by_name['policy_validation_parameter'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_common_dot_policy__pb2._POLICYVALIDATIONPARAMETER
_ADGROUPADOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__ad__pb2._ADGROUPAD
_ADGROUPADOPERATION.fields_by_name['update'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__ad__pb2._ADGROUPAD
_ADGROUPADOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPADOPERATION.fields_by_name['create'])
_ADGROUPADOPERATION.fields_by_name['create'].containing_oneof = _ADGROUPADOPERATION.oneofs_by_name['operation']
_ADGROUPADOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPADOPERATION.fields_by_name['update'])
_ADGROUPADOPERATION.fields_by_name['update'].containing_oneof = _ADGROUPADOPERATION.oneofs_by_name['operation']
_ADGROUPADOPERATION.oneofs_by_name['operation'].fields.append(
  _ADGROUPADOPERATION.fields_by_name['remove'])
_ADGROUPADOPERATION.fields_by_name['remove'].containing_oneof = _ADGROUPADOPERATION.oneofs_by_name['operation']
_MUTATEADGROUPADSRESPONSE.fields_by_name['results'].message_type = _MUTATEADGROUPADRESULT
DESCRIPTOR.message_types_by_name['GetAdGroupAdRequest'] = _GETADGROUPADREQUEST
DESCRIPTOR.message_types_by_name['MutateAdGroupAdsRequest'] = _MUTATEADGROUPADSREQUEST
DESCRIPTOR.message_types_by_name['AdGroupAdOperation'] = _ADGROUPADOPERATION
DESCRIPTOR.message_types_by_name['MutateAdGroupAdsResponse'] = _MUTATEADGROUPADSRESPONSE
DESCRIPTOR.message_types_by_name['MutateAdGroupAdResult'] = _MUTATEADGROUPADRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAdGroupAdRequest = _reflection.GeneratedProtocolMessageType('GetAdGroupAdRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETADGROUPADREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_ad_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupAdService.GetAdGroupAd][google.ads.googleads.v0.services.AdGroupAdService.GetAdGroupAd].
  
  
  Attributes:
      resource_name:
          The resource name of the ad to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetAdGroupAdRequest)
  ))
_sym_db.RegisterMessage(GetAdGroupAdRequest)

MutateAdGroupAdsRequest = _reflection.GeneratedProtocolMessageType('MutateAdGroupAdsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPADSREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_ad_service_pb2'
  ,
  __doc__ = """Request message for
  [AdGroupAdService.MutateAdGroupAds][google.ads.googleads.v0.services.AdGroupAdService.MutateAdGroupAds].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose ads are being modified.
      operations:
          The list of operations to perform on individual ads.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupAdsRequest)
  ))
_sym_db.RegisterMessage(MutateAdGroupAdsRequest)

AdGroupAdOperation = _reflection.GeneratedProtocolMessageType('AdGroupAdOperation', (_message.Message,), dict(
  DESCRIPTOR = _ADGROUPADOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_ad_service_pb2'
  ,
  __doc__ = """A single operation (create, update, remove) on an ad group ad.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which resource fields are modified
          in an update.
      policy_validation_parameter:
          Configuration for how policies are validated.
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new ad.
      update:
          Update operation: The ad is expected to have a valid resource
          name.
      remove:
          Remove operation: A resource name for the removed ad is
          expected, in this format:
          ``customers/{customer_id}/adGroupAds/{ad_group_id}_{ad_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.AdGroupAdOperation)
  ))
_sym_db.RegisterMessage(AdGroupAdOperation)

MutateAdGroupAdsResponse = _reflection.GeneratedProtocolMessageType('MutateAdGroupAdsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPADSRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_ad_service_pb2'
  ,
  __doc__ = """Response message for an ad group ad mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupAdsResponse)
  ))
_sym_db.RegisterMessage(MutateAdGroupAdsResponse)

MutateAdGroupAdResult = _reflection.GeneratedProtocolMessageType('MutateAdGroupAdResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEADGROUPADRESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.ad_group_ad_service_pb2'
  ,
  __doc__ = """The result for the ad mutate.
  
  
  Attributes:
      resource_name:
          The resource name returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateAdGroupAdResult)
  ))
_sym_db.RegisterMessage(MutateAdGroupAdResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\025AdGroupAdServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_ADGROUPADSERVICE = _descriptor.ServiceDescriptor(
  name='AdGroupAdService',
  full_name='google.ads.googleads.v0.services.AdGroupAdService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=922,
  serialized_end=1312,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAdGroupAd',
    full_name='google.ads.googleads.v0.services.AdGroupAdService.GetAdGroupAd',
    index=0,
    containing_service=None,
    input_type=_GETADGROUPADREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_ad__group__ad__pb2._ADGROUPAD,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002.\022,/v0/{resource_name=customers/*/adGroupAds/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAdGroupAds',
    full_name='google.ads.googleads.v0.services.AdGroupAdService.MutateAdGroupAds',
    index=1,
    containing_service=None,
    input_type=_MUTATEADGROUPADSREQUEST,
    output_type=_MUTATEADGROUPADSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0024\"//v0/customers/{customer_id=*}/adGroupAds:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_ADGROUPADSERVICE)

DESCRIPTOR.services_by_name['AdGroupAdService'] = _ADGROUPADSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v0/proto/services/media_file_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v0.proto.resources import media_file_pb2 as google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_media__file__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v0/proto/services/media_file_service.proto',
  package='google.ads.googleads.v0.services',
  syntax='proto3',
  serialized_pb=_b('\n?google/ads/googleads_v0/proto/services/media_file_service.proto\x12 google.ads.googleads.v0.services\x1a\x38google/ads/googleads_v0/proto/resources/media_file.proto\x1a\x1cgoogle/api/annotations.proto\",\n\x13GetMediaFileRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"x\n\x17MutateMediaFilesRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12H\n\noperations\x18\x02 \x03(\x0b\x32\x34.google.ads.googleads.v0.services.MediaFileOperation\"a\n\x12MediaFileOperation\x12>\n\x06\x63reate\x18\x01 \x01(\x0b\x32,.google.ads.googleads.v0.resources.MediaFileH\x00\x42\x0b\n\toperation\"d\n\x18MutateMediaFilesResponse\x12H\n\x07results\x18\x02 \x03(\x0b\x32\x37.google.ads.googleads.v0.services.MutateMediaFileResult\".\n\x15MutateMediaFileResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x86\x03\n\x10MediaFileService\x12\xa9\x01\n\x0cGetMediaFile\x12\x35.google.ads.googleads.v0.services.GetMediaFileRequest\x1a,.google.ads.googleads.v0.resources.MediaFile\"4\x82\xd3\xe4\x93\x02.\x12,/v0/{resource_name=customers/*/mediaFiles/*}\x12\xc5\x01\n\x10MutateMediaFiles\x12\x39.google.ads.googleads.v0.services.MutateMediaFilesRequest\x1a:.google.ads.googleads.v0.services.MutateMediaFilesResponse\":\x82\xd3\xe4\x93\x02\x34\"//v0/customers/{customer_id=*}/mediaFiles:mutate:\x01*B\xd5\x01\n$com.google.ads.googleads.v0.servicesB\x15MediaFileServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V0.Services\xca\x02 Google\\Ads\\GoogleAds\\V0\\Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_media__file__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GETMEDIAFILEREQUEST = _descriptor.Descriptor(
  name='GetMediaFileRequest',
  full_name='google.ads.googleads.v0.services.GetMediaFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.GetMediaFileRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=233,
)


_MUTATEMEDIAFILESREQUEST = _descriptor.Descriptor(
  name='MutateMediaFilesRequest',
  full_name='google.ads.googleads.v0.services.MutateMediaFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v0.services.MutateMediaFilesRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v0.services.MutateMediaFilesRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=355,
)


_MEDIAFILEOPERATION = _descriptor.Descriptor(
  name='MediaFileOperation',
  full_name='google.ads.googleads.v0.services.MediaFileOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v0.services.MediaFileOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v0.services.MediaFileOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=357,
  serialized_end=454,
)


_MUTATEMEDIAFILESRESPONSE = _descriptor.Descriptor(
  name='MutateMediaFilesResponse',
  full_name='google.ads.googleads.v0.services.MutateMediaFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v0.services.MutateMediaFilesResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=456,
  serialized_end=556,
)


_MUTATEMEDIAFILERESULT = _descriptor.Descriptor(
  name='MutateMediaFileResult',
  full_name='google.ads.googleads.v0.services.MutateMediaFileResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v0.services.MutateMediaFileResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=558,
  serialized_end=604,
)

_MUTATEMEDIAFILESREQUEST.fields_by_name['operations'].message_type = _MEDIAFILEOPERATION
_MEDIAFILEOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_media__file__pb2._MEDIAFILE
_MEDIAFILEOPERATION.oneofs_by_name['operation'].fields.append(
  _MEDIAFILEOPERATION.fields_by_name['create'])
_MEDIAFILEOPERATION.fields_by_name['create'].containing_oneof = _MEDIAFILEOPERATION.oneofs_by_name['operation']
_MUTATEMEDIAFILESRESPONSE.fields_by_name['results'].message_type = _MUTATEMEDIAFILERESULT
DESCRIPTOR.message_types_by_name['GetMediaFileRequest'] = _GETMEDIAFILEREQUEST
DESCRIPTOR.message_types_by_name['MutateMediaFilesRequest'] = _MUTATEMEDIAFILESREQUEST
DESCRIPTOR.message_types_by_name['MediaFileOperation'] = _MEDIAFILEOPERATION
DESCRIPTOR.message_types_by_name['MutateMediaFilesResponse'] = _MUTATEMEDIAFILESRESPONSE
DESCRIPTOR.message_types_by_name['MutateMediaFileResult'] = _MUTATEMEDIAFILERESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetMediaFileRequest = _reflection.GeneratedProtocolMessageType('GetMediaFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETMEDIAFILEREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Request message for
  [MediaFileService.GetMediaFile][google.ads.googleads.v0.services.MediaFileService.GetMediaFile]
  
  
  Attributes:
      resource_name:
          The resource name of the media file to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.GetMediaFileRequest)
  ))
_sym_db.RegisterMessage(GetMediaFileRequest)

MutateMediaFilesRequest = _reflection.GeneratedProtocolMessageType('MutateMediaFilesRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILESREQUEST,
  __module__ = 'google.ads.google_ads.v0.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Request message for
  [MediaFileService.MutateMediaFiles][google.ads.googleads.v0.services.MediaFileService.MutateMediaFiles]
  
  
  Attributes:
      customer_id:
          The ID of the customer whose media files are being modified.
      operations:
          The list of operations to perform on individual media file.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateMediaFilesRequest)
  ))
_sym_db.RegisterMessage(MutateMediaFilesRequest)

MediaFileOperation = _reflection.GeneratedProtocolMessageType('MediaFileOperation', (_message.Message,), dict(
  DESCRIPTOR = _MEDIAFILEOPERATION,
  __module__ = 'google.ads.google_ads.v0.proto.services.media_file_service_pb2'
  ,
  __doc__ = """A single operation to create media file.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          media file.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MediaFileOperation)
  ))
_sym_db.RegisterMessage(MediaFileOperation)

MutateMediaFilesResponse = _reflection.GeneratedProtocolMessageType('MutateMediaFilesResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILESRESPONSE,
  __module__ = 'google.ads.google_ads.v0.proto.services.media_file_service_pb2'
  ,
  __doc__ = """Response message for a media file mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateMediaFilesResponse)
  ))
_sym_db.RegisterMessage(MutateMediaFilesResponse)

MutateMediaFileResult = _reflection.GeneratedProtocolMessageType('MutateMediaFileResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEMEDIAFILERESULT,
  __module__ = 'google.ads.google_ads.v0.proto.services.media_file_service_pb2'
  ,
  __doc__ = """The result for the media file mutate.
  
  
  Attributes:
      resource_name:
          The resource name returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v0.services.MutateMediaFileResult)
  ))
_sym_db.RegisterMessage(MutateMediaFileResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n$com.google.ads.googleads.v0.servicesB\025MediaFileServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v0/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V0.Services\312\002 Google\\Ads\\GoogleAds\\V0\\Services'))

_MEDIAFILESERVICE = _descriptor.ServiceDescriptor(
  name='MediaFileService',
  full_name='google.ads.googleads.v0.services.MediaFileService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=607,
  serialized_end=997,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetMediaFile',
    full_name='google.ads.googleads.v0.services.MediaFileService.GetMediaFile',
    index=0,
    containing_service=None,
    input_type=_GETMEDIAFILEREQUEST,
    output_type=google_dot_ads_dot_googleads__v0_dot_proto_dot_resources_dot_media__file__pb2._MEDIAFILE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002.\022,/v0/{resource_name=customers/*/mediaFiles/*}')),
  ),
  _descriptor.MethodDescriptor(
    name='MutateMediaFiles',
    full_name='google.ads.googleads.v0.services.MediaFileService.MutateMediaFiles',
    index=1,
    containing_service=None,
    input_type=_MUTATEMEDIAFILESREQUEST,
    output_type=_MUTATEMEDIAFILESRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\0024\"//v0/customers/{customer_id=*}/mediaFiles:mutate:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_MEDIAFILESERVICE)

DESCRIPTOR.services_by_name['MediaFileService'] = _MEDIAFILESERVICE

# @@protoc_insertion_point(module_scope)
